@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2002, 2015 IBM Corporation and others.
+ * Copyright (c) 2002, 2018 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -64,7 +64,7 @@ public class CountResourcesAction implements IWorkbenchWindowActionDelegate {
 	@SuppressWarnings("rawtypes")
 	private List<IResource> getSelectedResources() {
 
-		List<IResource> resources = new LinkedList<IResource>();
+		List<IResource> resources = new LinkedList<>();
 
 		ISelectionService selectionService = window.getSelectionService();
 		ISelection selection = selectionService.getSelection();
