@@ -17,10 +17,12 @@ package org.eclipse.core.tests.resources;
 
 import java.io.*;
 import java.nio.charset.StandardCharsets;
+import java.util.Arrays;
 import junit.framework.Test;
 import junit.framework.TestSuite;
 import org.eclipse.core.internal.preferences.EclipsePreferences;
 import org.eclipse.core.internal.resources.CharsetDeltaJob;
+import org.eclipse.core.internal.resources.CharsetManager;
 import org.eclipse.core.resources.*;
 import org.eclipse.core.runtime.*;
 import org.eclipse.core.runtime.content.*;
@@ -565,10 +567,11 @@ public class CharsetTest extends ResourceTest {
 			}
 			//wait for all resource deltas
 			try {
-				Thread.sleep(5000);
+				Thread.sleep(500);
 			} catch (InterruptedException e) {
 				fail("3.0.1", e);
 			}
+			waitForCharsetManagerJob();
 			assertExistsInWorkspace("3.1", regularPrefs);
 			assertExistsInWorkspace("3.2", derivedPrefs);
 			assertTrue("3.3", derivedPrefs.isDerived());
@@ -582,10 +585,11 @@ public class CharsetTest extends ResourceTest {
 			}
 			//wait for all resource deltas
 			try {
-				Thread.sleep(5000);
+				Thread.sleep(500);
 			} catch (InterruptedException e) {
 				fail("4.0.1", e);
 			}
+			waitForCharsetManagerJob();
 			assertExistsInWorkspace("4.1", regularPrefs);
 			assertDoesNotExistInWorkspace("4.2", derivedPrefs);
 
@@ -601,6 +605,7 @@ public class CharsetTest extends ResourceTest {
 			} catch (CoreException e) {
 				fail("5.0", e);
 			}
+			waitForCharsetManagerJob();
 			assertTrue("5.1", backgroundVerifier.waitForEvent(10000));
 			assertTrue("5.2 " + backgroundVerifier.getMessage(), backgroundVerifier.isDeltaValid());
 			assertExistsInWorkspace("5.3", regularPrefs);
@@ -1153,7 +1158,20 @@ public class CharsetTest extends ResourceTest {
 	 * when we make encoding changes to containers (folders, projects, root).
 	 */
 	public void testDeltasContainer() {
-		CharsetVerifier verifier = new CharsetVerifier(CharsetVerifier.IGNORE_BACKGROUND_THREAD);
+		class CharsetVerifierWithExtraInfo extends CharsetVerifier {
+			CharsetVerifierWithExtraInfo() {
+				super(CharsetVerifier.IGNORE_BACKGROUND_THREAD);
+			}
+
+			@Override
+			public void verifyDelta(IResourceDelta delta) {
+				appendToMessage("Delta verification triggered:");
+				appendToMessage(Arrays.toString(Thread.currentThread().getStackTrace()));
+				super.verifyDelta(delta);
+			}
+		}
+
+		CharsetVerifier verifier = new CharsetVerifierWithExtraInfo();
 		IProject project = getWorkspace().getRoot().getProject(getUniqueString());
 		getWorkspace().addResourceChangeListener(verifier, IResourceChangeEvent.POST_CHANGE);
 		try {
@@ -1579,4 +1597,13 @@ public class CharsetTest extends ResourceTest {
 	private String getOtherCharset(String referenceCharset) {
 		return "MIK".equals(referenceCharset) ? "UTF-8" : "MIK";
 	}
+
+	private void waitForCharsetManagerJob() {
+		try {
+			Job.getJobManager().join(CharsetManager.class, null);
+		} catch (Exception e) {
+			fail("Exception occurred while waiting on jobs from " + CharsetManager.class, e);
+		}
+	}
+
 }
