@@ -20,12 +20,14 @@ import java.nio.file.Files;
 import java.nio.file.attribute.FileTime;
 import java.util.HashSet;
 import java.util.Set;
+import java.util.concurrent.atomic.AtomicBoolean;
 import org.eclipse.core.filesystem.*;
 import org.eclipse.core.internal.resources.Resource;
 import org.eclipse.core.internal.utils.FileUtil;
 import org.eclipse.core.internal.utils.UniversalUniqueIdentifier;
 import org.eclipse.core.resources.*;
 import org.eclipse.core.runtime.*;
+import org.eclipse.core.runtime.jobs.ISchedulingRule;
 import org.eclipse.core.runtime.jobs.Job;
 import org.eclipse.core.tests.harness.CoreTest;
 import org.eclipse.core.tests.harness.FileSystemHelper;
@@ -662,12 +664,6 @@ public abstract class ResourceTest extends CoreTest {
 	 */
 	public void ensureOutOfSync(final IFile file) {
 		modifyInFileSystem(file);
-		// Ensure the file is out-of-sync by waiting before touching it in the OS file system.
-		try {
-			Thread.sleep(5);
-		} catch (InterruptedException e) {
-			throw new AssertionError("unexpected interruption while ensuring that file is out-of-sync", e);
-		}
 		touchInFilesystem(file);
 		assertTrue("File not out of sync: " + file.getLocation().toOSString(), file.getLocation().toFile().lastModified() != file.getLocalTimeStamp());
 	}
@@ -685,7 +681,7 @@ public abstract class ResourceTest extends CoreTest {
 		// Manually check that the core.resource time-stamp is out-of-sync
 		// with the java.io.File last modified. #isSynchronized() will schedule
 		// out-of-sync resources for refresh, so we don't use that here.
-		for (int count = 0; count < 30 && getLastModifiedTime(location) == resource.getLocalTimeStamp(); count++) {
+		for (int count = 0; count < 30 && isInSync(resource); count++) {
 			try {
 				Thread.sleep(100);
 			} catch (InterruptedException e) {
@@ -701,6 +697,12 @@ public abstract class ResourceTest extends CoreTest {
 		assertTrue("File not out of sync: " + location.toOSString(), getLastModifiedTime(location) != resource.getLocalTimeStamp());
 	}
 
+	private boolean isInSync(IResource resource) {
+		IPath location = resource.getLocation();
+		long localTimeStamp = resource.getLocalTimeStamp();
+		return getLastModifiedTime(location) == localTimeStamp || location.toFile().lastModified() == localTimeStamp;
+	}
+
 	private long getLastModifiedTime(IPath fileLocation) {
 		IFileInfo fileInfo = EFS.getLocalFileSystem().getStore(fileLocation).fetchInfo();
 		return fileInfo.getLastModified();
@@ -714,9 +716,46 @@ public abstract class ResourceTest extends CoreTest {
 		return path.toFile().exists();
 	}
 
-	private boolean existsInWorkspace(IResource resource, boolean phantom) {
-		IResource target = getWorkspace().getRoot().findMember(resource.getFullPath(), phantom);
-		return target != null && target.getType() == resource.getType();
+	boolean existsInWorkspace(IResource resource, boolean phantom) {
+		class CheckIfResourceExistsJob extends Job {
+
+			private final AtomicBoolean resourceExists = new AtomicBoolean(false);
+
+			public CheckIfResourceExistsJob() {
+				super("Test " + ResourceTest.this.getName() + " checking whether resource exists: " + resource);
+			}
+
+			@Override
+			protected IStatus run(IProgressMonitor monitor) {
+				if (monitor.isCanceled()) {
+					return Status.CANCEL_STATUS;
+				}
+
+				IResource target = getWorkspace().getRoot().findMember(resource.getFullPath(), phantom);
+				boolean existsInWorkspace = target != null && target.getType() == resource.getType();
+				resourceExists.set(existsInWorkspace);
+
+				return Status.OK_STATUS;
+			}
+
+			boolean resourceExists() {
+				return resourceExists.get();
+			}
+		}
+
+		IWorkspace workspace = getWorkspace();
+		ISchedulingRule modifyWorkspaceRule = workspace.getRuleFactory().modifyRule(workspace.getRoot());
+
+		CheckIfResourceExistsJob checkIfResourceExistsJob = new CheckIfResourceExistsJob();
+		checkIfResourceExistsJob.setRule(modifyWorkspaceRule);
+		checkIfResourceExistsJob.schedule();
+		try {
+			checkIfResourceExistsJob.join(30_000, getMonitor());
+		} catch (Exception e) {
+			fail("Joining job to check whether resource exists in workspace failed with exception", e);
+		}
+
+		return checkIfResourceExistsJob.resourceExists();
 	}
 
 	/**
